@@ -169,46 +169,59 @@ def parseWaveformFiles(directory, run, subrun, headertype):
 		if cos is not None:
 			cosmics.append(cos)
 	#make singular arrays for each of these
-	singles = np.concatenate(singles)
-	coincidences = np.concatenate(coincidences)
-	pulsers = np.concatenate(pulsers)
-	baselines = np.concatenate(baselines)
-	cosmics = np.concatenate(cosmics)
-	#now change the array types to match the actual data present
-	#the shaped has to be 2 dimensional, otherwise it's meaningless data
-	if singles.ndim == 2:
-		wavelength = singles.shape[1] - 13
-		dtype = ff.headWaveType(wavelength, 'Nab', 4)
-		singles = singles.view(dtype)[:,0]
-		singles = prepareDataset(singles)
+	if len(singles) > 0:
+		singles = np.concatenate(singles)
+		if singles.ndim == 2:
+			wavelength = singles.shape[1] - 13
+			dtype = ff.headWaveType(wavelength, 'Nab', 4)
+			singles = singles.view(dtype)[:,0]
+			singles = prepareDataset(singles)
+		else:
+			singles = None
 	else:
 		singles = None
-	if coincidences.ndim == 2:
-		wavelength = coincidences.shape[1] - 13
-		dtype = ff.headWaveType(wavelength, 'Nab', 4)
-		coincidences = coincidences.view(dtype)[:,0]
-		coincidences = prepareDataset(coincidences)
+	if len(coincidences) > 0:
+		coincidences = np.concatenate(coincidences)
+		if coincidences.ndim == 2:
+			wavelength = coincidences.shape[1] - 13
+			dtype = ff.headWaveType(wavelength, 'Nab', 4)
+			coincidences = coincidences.view(dtype)[:,0]
+			coincidences = prepareDataset(coincidences)
+		else:
+			coincidences = None
 	else:
 		coincidences = None
-	if pulsers.ndim == 2:
-		wavelength = pulsers.shape[1] - 13
-		dtype = ff.headWaveType(wavelength, 'Nab', 4)
-		pulsers = pulsers.view(dtype)[:,0]
-		pulsers = prepareDataset(pulsers)
+	if len(pulsers) > 0:
+		pulsers = np.concatenate(pulsers)
+		if pulsers.ndim == 2:
+			wavelength = pulsers.shape[1] - 13
+			dtype = ff.headWaveType(wavelength, 'Nab', 4)
+			pulsers = pulsers.view(dtype)[:,0]
+			pulsers = prepareDataset(pulsers)
+		else:
+			pulsers = None
 	else:
 		pulsers = None
-	if baselines.ndim == 2:
-		wavelength = baselines.shape[1] - 13
-		dtype = ff.headWaveType(wavelength, 'Nab', 4)
-		baselines = baselines.view(dtype)[:,0]
-		baselines = prepareDataset(baselines)
+	if len(baselines) > 0:
+		baselines = np.concatenate(baselines)
+		if baselines.ndim == 2:
+			wavelength = baselines.shape[1] - 13
+			dtype = ff.headWaveType(wavelength, 'Nab', 4)
+			baselines = baselines.view(dtype)[:,0]
+			baselines = prepareDataset(baselines)
+		else:
+			baselines = None
 	else:
 		baselines = None
-	if cosmics.ndim == 2:
-		wavelength = cosmics.shape[1] - 13
-		dtype = ff.headWaveType(wavelength, 'Nab', 4)
-		cosmics = cosmics.view(dtype)[:,0]
-		cosmics = prepareDataset(cosmics)
+	if len(cosmics) > 0:
+		cosmics = np.concatenate(cosmics)
+		if cosmics.ndim == 2:
+			wavelength = cosmics.shape[1] - 13
+			dtype = ff.headWaveType(wavelength, 'Nab', 4)
+			cosmics = cosmics.view(dtype)[:,0]
+			cosmics = prepareDataset(cosmics)
+		else:
+			cosmics = None
 	else:
 		cosmics = None
 	return singles, coincidences, pulsers, baselines, cosmics
