@@ -219,7 +219,7 @@ class waveformFile:
 			if self.getFileStartTime() is not None:
 				startTime = self.getFileStartTime()
 				#now shift all of the FPGA times by this
-				self.__headers['unix timestamp'] = self.__headers['timestamp'] + startTime / (4E-9)
+				self.__headers['unix timestamp'] = self.__headers['timestamp'] + startTime[0] / (4E-9)
 		else:
 			self.__headers = None
 			self.__waves = None
